/**
 * Module dependencies
 */

var exists = require('fs').existsSync;
var join = require('path').join;
var resolve = require('path').resolve;

/**
 * Resolve the path to the app
 *
 * @param 
 */

exports.resolve = function(path) {
  if (path) return resolve(process.cwd(), path);

  try {
    // Try to find it in the `package.json`
    return join(process.cwd(), require(join(process.cwd(), 'package.json')).main);
  }
  catch (e) {
    // Default to `app.js`
    return join(process.cwd(), 'app');
  }
};

/**
 * Output fatal error message and exit.
 *
 * @param {String} msg
 * @api private
 */

exports.fatal = function(){
  console.error();
  exports.error.apply(null, arguments);
  console.error();
  process.exit(1);
};

/**
 * Log the given `type` with `msg`.
 *
 * @param {String} type
 * @param {String} msg
 * @api public
 */

exports.log = function(type, msg, color){
  color = color || '36';
  var w = 10;
  var len = Math.max(0, w - type.length);
  var pad = Array(len + 1).join(' ');
  console.log('  \033[' + color + 'm%s\033[m : \033[90m%s\033[m', pad + type, msg);
};

/**
 * Log warning message with `type` and `msg`.
 *
 * @param {String} type
 * @param {String} msg
 * @api public
 */

exports.warn = function(type, msg){
  exports.log(type, msg, '33');
};

/**
 * Output error message.
 *
 * @param {String} msg
 * @api private
 */

exports.error = function(msg){
  var w = 10;
  var type = 'error';
  var len = Math.max(0, w - type.length);
  var pad = Array(len + 1).join(' ');
  console.error('  \033[31m%s\033[m : \033[90m%s\033[m', pad + type, msg);
};
